@@ -1,4 +1,8 @@
 # -*- coding: utf-8 -*-
+try:
+    from libs.modelmixins import UrlMixin
+except ImportError:
+    from cryotec_server.libs.modelmixins import UrlMixin
 try:
     from django.db import models
 except ImportError:
@@ -53,4 +57,4 @@ class ChecklistAnswer(models.Model):
         verbose_name_plural = u"Чеклист-ответы"
 
 
-    
\ No newline at end of file
+    
