@@ -7,8 +7,13 @@ except ImportError:
 
 try:
     from django.db import models
+    from tinymce import models as tinymce_models
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^tinymce\.models\.HTMLField"])
 except ImportError:
     from qtdjango import models
+    from qtdjango import models as tinymce_models
+
 from clients.models import Client
 
 class MachineType(models.Model, UrlMixin):
@@ -43,6 +48,9 @@ class MachineMark(models.Model, UrlMixin):
     month_default = models.IntegerField(u"Количество месяцев между профосмотрами (по умолчанию)", blank=True, null=True)
     motohours_default = models.IntegerField(u"Количество моточасов между техобслуживаниями (по умолчанию)", blank=True, null=True)
 
+    manufacturer = models.CharField(u"Производитель", max_length=128)
+
+    info = tinymce_models.HTMLField(u"Дополнительная информация", null=True, blank=True)
 
 
     class Meta:
@@ -54,16 +62,14 @@ class MachineMark(models.Model, UrlMixin):
         return u"%s" % self.name
     
 
-
-
 class Machine(models.Model, UrlMixin):
     """
     Конкретная машина
     """
     serial = models.CharField(u"Серийный номер", max_length=128,  blank=True, null=True)
     """Серийный номер машины"""
-    client = models.ForeignKey(Client, verbose_name=u"Клиент, которому принадлежит оборудование",   related_name="machines")
-    customer = models.ForeignKey(Client, verbose_name=u"Клиент, который купил оборудование",  blank=True, null=True,  related_name="machines_customer")
+    client = models.ForeignKey(Client, verbose_name=u"Пользователь",   related_name="machines")
+    customer = models.ForeignKey(Client, verbose_name=u"Покупатель",  blank=True, null=True,  related_name="machines_customer")
 
     """Клиент, которому продана машина"""
     alias = models.CharField(u"Псевдоним", max_length=128, blank=True)
@@ -73,7 +79,9 @@ class Machine(models.Model, UrlMixin):
 
     date = models.DateField(u"Дата ввода в эксп.")
     """Дата ввода в эксплуатацию оборудования"""
+   
 
+    manufacturing_year = models.IntegerField(u"Год производства")
     month = models.IntegerField(u"Количество месяцев между профосмотрами", blank=True, null=True)
     motohours = models.IntegerField(u"Количество моточасов между техобслуживаниями", blank=True, null=True)
 
@@ -89,6 +97,26 @@ class Machine(models.Model, UrlMixin):
         else:
             return u"%s_%s" % (self.client.name, self.machinemark)
         
+    def tohtml(self):
+        table = (
+            (u"Оборудование", self),
+            (u"Производитель", self.machinemark.manufacturer),
+            (u"Серийный номер", self.serial),
+            (u"Год производства", self.manufacturing_year),
+            (u"Покупатель", self.customer),
+            (u"Пользователь", self.client),
+            (u"Место установки", self.client.address_machine),
+#            (u"Контактное лицо", self.client.contactface_set.all()),
+            (u"Дата ввода в эксплуатацию", self.date),
+#            (u"Срок гарантии", ),
+        )
+        html = u"<table>"
+        for rowname, rowvalue in table:
+            html += u"<tr><td><b>{0}</b></td> <td>{1}</td></tr>".format(rowname, rowvalue)
+
+        html +=u"</table><br>"
+        html += self.machinemark.info
+        return html
 
     
     def save(self):
